@@ -322,7 +322,7 @@ class RestAPI(object):
 		for uid, _api_key_ in self.uid_api_keys.items():
 			if str(_api_key_) == str(api_key):
 				return r3sponse.success_response("Successfully found the uid for the specified api key.", {"uid":uid})
-		return r3sponse.error_response(f"Failed to find the uid for the specified api key, uid_api_keys: {json.dumps(self.uid_api_keys, indent=4)}.")
+		return r3sponse.error_response(f"Failed to find the uid for the specified api key, api_key {api_key} VS uid_api_keys: {json.dumps(self.uid_api_keys, indent=4)}.")
 
 		#
 	# user functions.
